summaryrefslogtreecommitdiffstats
path: root/src/import/chips/p9/procedures/hwp/accessors/p9_mvpd_ring_funcs.H
diff options
context:
space:
mode:
authorClaus Michael Olsen <cmolsen@us.ibm.com>2017-08-03 22:50:50 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-08-18 00:31:44 -0400
commitb0506146ce9a416ed84c788d94c3ee8886290468 (patch)
tree23483fd3e5e7210a49f6272c3132a270e78c60e5 /src/import/chips/p9/procedures/hwp/accessors/p9_mvpd_ring_funcs.H
parentf6df91cc6f5beee527aae6acb180ba20ad9c4269 (diff)
downloadtalos-hostboot-b0506146ce9a416ed84c788d94c3ee8886290468.tar.gz
talos-hostboot-b0506146ce9a416ed84c788d94c3ee8886290468.zip
L3 review and update to p9_mvpd_ring_funcs_errors.xml and
associated files. Included in this commit: - Greatly improved FFDC capturing and renaming of RC variables. - Addition of fapiTarget as parm to several functions. - Minor cleanup of APIs. Change-Id: Icb2a2677ddb5c7faa56092542a127d8415066765 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/44200 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Reviewed-by: Richard J. Knight <rjknight@us.ibm.com> Tested-by: Hostboot CI <hostboot-ci+hostboot@us.ibm.com> Reviewed-by: Jennifer A. Stofer <stofer@us.ibm.com> Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/44201 Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Tested-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/import/chips/p9/procedures/hwp/accessors/p9_mvpd_ring_funcs.H')
-rw-r--r--src/import/chips/p9/procedures/hwp/accessors/p9_mvpd_ring_funcs.H14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/import/chips/p9/procedures/hwp/accessors/p9_mvpd_ring_funcs.H b/src/import/chips/p9/procedures/hwp/accessors/p9_mvpd_ring_funcs.H
index f2045936d..b8fae9fd5 100644
--- a/src/import/chips/p9/procedures/hwp/accessors/p9_mvpd_ring_funcs.H
+++ b/src/import/chips/p9/procedures/hwp/accessors/p9_mvpd_ring_funcs.H
@@ -47,10 +47,10 @@ enum mvpdRingFuncOp
};
typedef ReturnCode (*mvpdRingFuncs_FP_t) (
+ const Target<TARGET_TYPE_PROC_CHIP>&,
mvpdRingFuncOp,
MvpdRecord,
MvpdKeyword,
- const Target<TARGET_TYPE_PROC_CHIP>&,
const uint8_t,
const uint64_t,
const uint8_t,
@@ -67,28 +67,28 @@ extern "C"
* detailed comments on get and set are in the
* getMvpdRing.H and setMvpdRing.H and apply here as well.
*
+ * @param i_fapiTarget - cpu target
* @param i_mvpdRingFuncOp - indicate get or set via enum mvpdRingFuncOp
* @param i_record - Record enumerator
* @param i_keyword - Keyword enumerator
- * @param i_fapiTarget - cpu target
* @param i_chipletId - Chiplet ID
* @param i_evenOddMask - Even (0) or odd (1) EX. Disregarded for other chiplets.
* @param i_ringId - Ring ID
* @param i_pRingBuf - The buffer to receive or send the ring
* @param io_rRingBufsize - Size of ring / ring buffer
*
* @return fapi2::ReturnCode - FAPI_RC_SUCCESS if success,
* relevant error code for failure.
*/
- ReturnCode mvpdRingFunc( mvpdRingFuncOp i_mvpdRingFuncOp,
+ ReturnCode mvpdRingFunc( const Target<TARGET_TYPE_PROC_CHIP>&
+ i_fapiTarget,
+ mvpdRingFuncOp i_mvpdRingFuncOp,
MvpdRecord i_record,
MvpdKeyword i_keyword,
- const Target<TARGET_TYPE_PROC_CHIP>&
- i_fapiTarget,
const uint8_t i_chipletId,
const uint8_t i_evenOdd,
const uint8_t i_ringId,
- uint8_t* i_pRingBuf,
+ uint8_t* o_pRingBuf,
uint32_t& io_rRingBufsize );
} // extern "C"
OpenPOWER on IntegriCloud
@@ -67,28 +67,28 @@ extern "C"
* @param i_evenOddMask - Even (0) or odd (1) EX. Disregarded for other chiplets.
* @param i_ringId - Ring ID
- * @param i_pRingBuf - The buffer to receive or send the ring
+ * @param o_pRingBuf - The buffer to receive or send the ring
* @param io_rRingBufsize - Size of ring / ring buffer
*